@@ -1,6 +1,6 @@
 package PDF::Boxer;
 {
-  $PDF::Boxer::VERSION = '0.002';
+  $PDF::Boxer::VERSION = '0.003';
 }
 use Moose;
 
@@ -26,13 +26,18 @@ coerce 'PDF::Boxer::Doc'
 
 has 'debug'   => ( isa => 'Bool', is => 'ro', default => 0 );
 
-has 'doc' => ( isa => 'PDF::Boxer::Doc', is => 'ro', coerce => 1 );
+has 'doc' => ( isa => 'PDF::Boxer::Doc', is => 'ro', coerce => 1, lazy_build => 1 );
 
 has 'max_width' => ( isa => 'Int', is => 'rw', default => 595 );
 has 'max_height'  => ( isa => 'Int', is => 'rw', default => 842 );
 
 has 'box_register' => ( isa => 'HashRef', is => 'ro', default => sub{{}} ); 
 
+sub _build_doc{
+  my ($self) = @_;
+  return PDF::Boxer::Doc->new;
+}
+
 sub register_box{
   my ($self, $box) = @_;
   return unless $box->name;
@@ -96,7 +101,7 @@ PDF::Boxer - Create PDFs from a simple box markup language.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -191,10 +196,6 @@ each named element is added to an internal register upon creation.
 
 get an element from the register.
 
-=head1 NAME
-
-PDF::Boxer
-
 =head1 MARKUP
 
 For a single page document the parent element may be a row, column, or grid.
@@ -246,12 +247,12 @@ align right or center instead of the default left.
 
 background is set as a hexadecimal color.
 
-=item border
-
-border width set in pixels
-
 =item border_color
 
+  border_color="#FF0000"
+
+border_color is set as a hexadecimal color.
+
 =item font
 
 =item grow
